@@ -18,12 +18,14 @@ INSTALLED_APPS = [
     # See https://github.com/jbalogh/django-nose/issues/15
     'lizard_map',
     'lizard_ui',
+    'lizard_security',
     'staticfiles',
     'compressor',
     'piston',
     'south',
     'django_nose',
     'debug_toolbar',
+    'djangorestframework',
     'django_extensions',
     'django.contrib.gis',
     'django.contrib.admin',
@@ -62,6 +64,7 @@ MEDIA_ROOT = os.path.join(BUILDOUT_DIR, 'var', 'media')
 STATIC_ROOT = os.path.join(BUILDOUT_DIR, 'var', 'static')
 MEDIA_URL = '/media/'
 STATIC_URL = '/static_media/'
+ADMIN_MEDIA_PREFIX = STATIC_URL + 'admin/'
 
 LOGGING = setup_logging(BUILDOUT_DIR)
 
