@@ -116,6 +116,29 @@ class WorkspaceMixin(object):
                 'javascript_hover_handler', None)
         return self._javascript_hover_handler
 
+    def extra_wms_layers(self):
+        """Overwrite to add custom WMS layers to your view.
+
+        Every item should be a dict with five items. ``models.py`` puts the
+        following in there for example::
+
+               {'wms_id': workspace_item.id,
+                'name': workspace_item.name,
+                'url': adapter_layer.get('url', ''),
+                'params': adapter_layer.get('params', '{}'),
+                'options': adapter_layer.get('options', '{}'),
+               }
+
+        """
+        return []
+
+    def wms_layers(self):
+        """Return the workspace's and our own extra wms layers."""
+        from_workspace = self.workspace().wms_layers()
+        extra = self.extra_wms_layers() or []
+        # ^^^ To work around '[] + None' error.
+        return from_workspace + extra
+
 
 class WorkspaceEditMixin(WorkspaceMixin):
     def workspace_edit(self):
@@ -172,21 +195,21 @@ class MapMixin(object):
         return ""
 
     @property
-    def maps(self):
-        if not hasattr(self, '_maps'):
-            self._maps = BackgroundMap.objects.filter(active=True)
-        return self._maps
+    def backgrounds(self):
+        if not hasattr(self, '_backgrounds'):
+            self._backgrounds = BackgroundMap.objects.filter(active=True)
+        return self._backgrounds
 
     def has_google(self):
         # For the client side to determine is there is a google map.
-        if self.maps.filter(
+        if self.backgrounds.filter(
             layer_type=BackgroundMap.LAYER_TYPE_GOOGLE).count() > 0:
             return True
         return False
 
     def background_maps(self):
-        if self.maps:
-            return self.maps
+        if self.backgrounds:
+            return self.backgrounds
         logger.warn("No background maps are active. Taking default.")
         return [BackgroundMap(
                     name='Default map',
@@ -296,7 +319,7 @@ class CrumbsMixin(object):
 
 class AppView(WorkspaceEditMixin, GoogleTrackingMixin, CollageMixin, DateRangeMixin, MapMixin,
               UiView):
-    """Main map view (using twitter bootstrap). Replaces AppView."""
+    """Main map view (using twitter bootstrap)."""
 
     @property
     def show_secondary_sidebar_title(self):
@@ -328,7 +351,7 @@ class AppView(WorkspaceEditMixin, GoogleTrackingMixin, CollageMixin, DateRangeMi
     @property
     def content_actions(self):
         """Add default-location-zoom."""
-        actions = super(MapView, self).content_actions
+        actions = super(AppView, self).content_actions
         zoom_to_default = Action(
             name=_('Default zoom'),
             description=_('Zoom to default location'),
@@ -1867,7 +1890,7 @@ class AdapterValuesView(AdapterMixin, UiView):
                 request, *args, **kwargs)
 
 
-class HomepageView(MapView, IconView):
+class HomepageView(AppView, IconView):
     template_name = 'lizard_map/icons.html'
 
 
